pub struct SetProgramFeeInstructionArgs {
pub new_fee_bps: u16,
}Fields
new_fee_bps: u16Trait Implementations
Sourceimpl BorshDeserialize for SetProgramFeeInstructionArgswhere
u16: BorshDeserialize,
impl BorshDeserialize for SetProgramFeeInstructionArgswhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetProgramFeeInstructionArgswhere
u16: BorshSerialize,
impl BorshSerialize for SetProgramFeeInstructionArgswhere
u16: BorshSerialize,
Sourceimpl Clone for SetProgramFeeInstructionArgs
impl Clone for SetProgramFeeInstructionArgs
Sourcefn clone(&self) -> SetProgramFeeInstructionArgs
fn clone(&self) -> SetProgramFeeInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetProgramFeeInstructionArgs
impl Debug for SetProgramFeeInstructionArgs
Sourceimpl PartialEq for SetProgramFeeInstructionArgs
impl PartialEq for SetProgramFeeInstructionArgs
Sourcefn eq(&self, other: &SetProgramFeeInstructionArgs) -> bool
fn eq(&self, other: &SetProgramFeeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetProgramFeeInstructionArgs
impl StructuralPartialEq for SetProgramFeeInstructionArgs