pub struct CreateMetadataAccountArgsV3 {
pub data: DataV2,
pub is_mutable: bool,
pub collection_details: Option<u8>,
}Fields
data: DataV2is_mutable: boolcollection_details: Option<u8>Trait Implementations
Sourceimpl BorshDeserialize for CreateMetadataAccountArgsV3
impl BorshDeserialize for CreateMetadataAccountArgsV3
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateMetadataAccountArgsV3
impl Clone for CreateMetadataAccountArgsV3
Sourcefn clone(&self) -> CreateMetadataAccountArgsV3
fn clone(&self) -> CreateMetadataAccountArgsV3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateMetadataAccountArgsV3
impl Debug for CreateMetadataAccountArgsV3
impl Eq for CreateMetadataAccountArgsV3
impl StructuralPartialEq for CreateMetadataAccountArgsV3